import logging
import logging.handlers
import sys
import os

DEFAULT_LOG_FORMATTER = logging.Formatter(
    '%(asctime)s %(levelname)-8s %(name)s:%(lineno)s '
    '[%(threadName)s] [%(funcName)s] - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
# DEFAULT_LOG_PATH = "/var/log/nsxi/ids-server"
DEFAULT_LOG_PATH = os.getenv('IDS_SERVER_LOG_NAME', '/var/log/nsxi/ids-server')
DEFAULT_LOG_LEVEL = os.getenv('IDS_SERVER_LOG_LEVEL', 'INFO')


def get_log_level(log_level_str):
    log_level = {
        'INFO': logging.INFO,
        'DEBUG': logging.DEBUG,
        'WARNING': logging.WARNING,
        'ERROR': logging.ERROR,
        'CRITICAL': logging.CRITICAL,
    }
    return log_level.get(log_level_str, "INFO")


def setup_logger():
    log = logging.getLogger()
    log_level = get_log_level(DEFAULT_LOG_LEVEL)
    log.setLevel(log_level)

    fh_dbg = logging.handlers.RotatingFileHandler(
        "%s.DEBUG.log" % DEFAULT_LOG_PATH, maxBytes=10 ** 8, backupCount=10)
    fh_dbg.setLevel(logging.DEBUG)
    fh_dbg.setFormatter(DEFAULT_LOG_FORMATTER)
    log.addHandler(fh_dbg)
    fh_info = logging.handlers.RotatingFileHandler(
        "%s.INFO.log" % DEFAULT_LOG_PATH, maxBytes=10 ** 8, backupCount=10)
    fh_info.setLevel(logging.INFO)
    fh_info.setFormatter(DEFAULT_LOG_FORMATTER)
    log.addHandler(fh_info)
    fh_out = logging.StreamHandler(sys.stdout)
    fh_out.setLevel(logging.INFO)
    fh_out.setFormatter(DEFAULT_LOG_FORMATTER)
    log.addHandler(fh_out)
    return log


def get_logger(name):
    if name is None:
        return logging.getLogger()
    else:
        return logging.getLogger(name)
